==> mgb-0.6.3.tar.bz2: language/lang_italian_utf8/lang_main.php <==
<?php
	
	/*
	MGB 0.6 - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =============================== //
	// lang_italian.php - Italiano 1.0 //
	// =============================== //
	//
	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// ITALIAN strings of index.php
	$lang['install_directory_exists'] = "La directory 'install' esiste già.<br />Per tua sicurezza dovresti cancellarla!<br>Ma non scordarti di lanciare <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> dopo un aggiornamento!";
	$lang['new_entry'] = "scrivi un nuovo post";
	$lang['new_entry_descr'] = "qui puoi scrivere un nuovo post nel guestbook";
	$lang['contact'] = "contatti";
	$lang['contact_descr'] = "Qui puoi contattare l'amministratore";
	$lang['adminpanel'] = "amministrazione";
	$lang['adminpanel_descr'] = "Vai al Login";
	$lang['entry'] = "post";
	$lang['entries'] = "post";
	$lang['no_entries'] = "Non ci sono post al momento<br>. Vuoi essere il primo?"; // "Vuoi essere il primo?" stands for do u want to be the first?
	$lang['entries_on_pages'] = "Post in {PAGES} pagine";
	$lang['page_forwards'] = "Sfoglia una pagina in avanti";
	$lang['page_backwards']	= "Sfoglia una pagina indietro";
	$lang['anchor']	= "Vai direttamente a questo post";
	$lang['from'] = "da";
	$lang['at'] = "a";
	$lang['oclock']	= "am/pm(?!)";
	$lang['comment'] = "commento";
	$lang['email_yes'] = "eMail da {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} non riceverà e-mail dal guestbook.";
	$lang['hp_of'] = "Homepage per {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar per {ENTRY_NAME}";

	// ENGLISH strings of newentry.php
	$lang['name'] = "Nome:";
	$lang['city'] = "Città:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Homepage:";
	$lang['message'] = "Il tuo messaggio:";
	$lang['necessary_fields'] = "[ I campi necessari sono marcati con un asterisco (*) ]";
	$lang['user_notification'] = "Notifica via e-mail se il post è stato pubblicato o un commento è stato postato.";
	$lang['user_show_email'] = "Mostra il mio indirizzo e-mail nel guestbook per permettere ad altri utenti di spedirti una mail. Se la protezione antispam è attivata, nessuno vedrà direttamente l'indirizzo eMail ma potrà comunque spedirtela attraverso un form.";
	$lang['send'] = "Invia";
	$lang['errormessage1'] = "Per favore inserisci un messaggio!";
	$lang['errormessage2'] = "Per favore fornisci un indirizzo e-mail valido!";
	$lang['errormessage3'] = "Per favore inserisci il tuo nome!";
	$lang['errormessage4'] = "non è un indirizzo<br>valido!";
	$lang['errormessage5'] = "non è un numero<br>ICQ valido!";
	$lang['errormessage6'] = "Il blocco IP ti vieta di postare ulteriormente!";
	$lang['errormessage7'] = "Il captcha non è stato risolto oppure è stato risolto incorrettamente!";
	$lang['errormessage8'] = "Quest'utente non riceverà e-mail!";
	$lang['errormessage9'] = "E' avvenuto un errore nel tentativo di spedire la tua e-mail!";
	$lang['security_code'] = "codice di sicurezza (captcha)";	
	$lang['captcha_what_is_that'] = "Cos'è questo?";
	$lang['captcha_wikipedia'] = "http://it.wikipedia.org/wiki/CAPTCHA";
	$lang['captcha_tooltip'] = "Un nuovo post nel guestbook entry una eMail richiede di risolvere il captcha per impedire post automatici da parte di programmi. Per favore digita tutte le lettere MAIUSCOLE. Se il codice è illeggibile, lascia il campo vuoto e clicca su ''Invia''. In questo modo verrà generato un nuovo captcha. I dati negli altri campi verranno mantenuti. Se non viene generato un nuovo codice, per favore eseguire un clic con il tasto destro del mouse e ''ricaricare'' oppure premere [CTRL]+[R].";
	$lang['back_to_mainpage'] = "Torna alla pagina principale";
	$lang['back'] = "Indietro";
	$lang['entry_success_mod'] = "Il tuo post è stato salvato con successo.<br>Sarà validato dall'admin e poi pubblicato.";
	$lang['entry_success'] = "Il tuo post è stato salvato con successo. Puoi vederlo subito.";
	$lang['forwarding'] = "Sarai redirettato automaticamente entro 5 secondi. Se così non fosse, clicca su ''Torna alla pagina principale''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "grassetto";
	$lang['bbcode_help_italic'] = "corsivo";
	$lang['bbcode_help_url'] = "ancora";
	$lang['bbcode_textsize'] = "grandezza del testo";
	$lang['bbcode_extrasmall'] = "piccolissimo";
	$lang['bbcode_small'] = "piccolo";
	$lang['bbcode_default'] = "normale";
	$lang['bbcode_big'] = "grande";
	$lang['bbcode_extrabig'] = "grandissimo";
	$lang['bbcode_textcolor'] = "colore del testo";
	$lang['bbcode_help_size'] = "grandezza del testo";
	$lang['smileys'] = "smileys:";
	$lang['sendmail_admin_title'] = "Nuovo post da '{NAME}'";
	$lang['sendmail_user_title'] = "Il tuo post presso {DOMAIN}";		

	// ITALIAN strings of email.php
	$lang['email_name'] = "Il tuo nome:";
	$lang['email_email'] = "La tua eMail:";
	$lang['email_message'] = "Il tuo messaggio:";
	$lang['email_sent_to'] = "Questa eMail verrà spedita a:";
	$lang['email_send'] = "Invia";
	$lang['email_caption'] = "eMail da '{NAME}' sul guestbook di {DOMAIN}";
	$lang['email_sender'] = "Mittente:";
	$lang['email_receiver'] = "Destinatario:";
	$lang['email_from'] = "da:";
	$lang['email_sendcopytome'] = "Voglio ricevere una copia di questa eMail.";
	$lang['email_success'] = "La tua email è stata spedita con successo all'utente.";
?>

==> mgb-0.6.4.tar.bz2: language/lang_italian_utf8/lang_main.php <==
<?php
	
	/*
	MGB 0.6 - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// =============================== //
	// lang_italian.php - Italiano 1.0 //
	// =============================== //
	//
	// This language file was translated by Christian Castelli alias VooDoo (voodoo81people@gmail.com) 
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// ITALIAN strings of index.php
	$lang['install_directory_exists'] = "La directory 'install' esiste già.<br />Per tua sicurezza dovresti cancellarla!<br>Ma non scordarti di lanciare <a href=\"install/upgrade.php\" title=\"Upgrade\">upgrade.php</a> dopo un aggiornamento!";
	$lang['new_entry'] = "scrivi un nuovo post";
	$lang['new_entry_descr'] = "qui puoi scrivere un nuovo post nel guestbook";
	$lang['contact'] = "contatti";
	$lang['contact_descr'] = "Qui puoi contattare l'amministratore";
	$lang['adminpanel'] = "amministrazione";
	$lang['adminpanel_descr'] = "Vai al Login";
	$lang['entry'] = "post";
	$lang['entries'] = "post";
	$lang['no_entries'] = "Non ci sono post al momento.<br>Vuoi essere il primo?"; // "Vuoi essere il primo?" stands for do u want to be the first?
	$lang['entries_on_pages'] = "Post in {PAGES} pagine";
	$lang['page_forwards'] = "Sfoglia una pagina in avanti";
	$lang['page_backwards']	= "Sfoglia una pagina indietro";
	$lang['anchor']	= "Vai direttamente a questo post";
	$lang['from'] = "da";
	$lang['at'] = "a";
	$lang['oclock']	= "am/pm(?!)";
	$lang['comment'] = "commento";
	$lang['email_yes'] = "eMail da {ENTRY_NAME}";
	$lang['email_no'] = "{ENTRY_NAME} non riceverà e-mail dal guestbook.";
	$lang['hp_of'] = "Homepage per {ENTRY_NAME}";
	$lang['gravatar'] = "Gravatar per {ENTRY_NAME}";

	// ENGLISH strings of newentry.php
	$lang['name'] = "Nome:";
	$lang['city'] = "Città:";
	$lang['email'] = "eMail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['homepage'] = "Homepage:";
	$lang['message'] = "Il tuo messaggio:";
	$lang['necessary_fields'] = "[ I campi necessari sono marcati con un asterisco (*) ]";
	$lang['user_notification'] = "Notifica via e-mail se il post è stato pubblicato o un commento è stato postato.";
	$lang['user_show_email'] = "Mostra il mio indirizzo e-mail nel guestbook per permettere ad altri utenti di spedirti una mail. Se la protezione antispam è attivata, nessuno vedrà direttamente l'indirizzo eMail ma potrà comunque spedirtela attraverso un form.";
	$lang['send'] = "Invia";
	$lang['preview'] = "Previsione";
	$lang['errormessage1'] = "Per favore inserisci un messaggio!";
	$lang['errormessage2'] = "Per favore fornisci un indirizzo e-mail valido!";
	$lang['errormessage3'] = "Per favore inserisci il tuo nome!";
	$lang['errormessage4'] = "non è un indirizzo<br>valido!";
	$lang['errormessage5'] = "non è un numero<br>ICQ valido!";
	$lang['errormessage6'] = "Il blocco IP ti vieta di postare ulteriormente!";
	$lang['errormessage7'] = "Il captcha non è stato risolto oppure è stato risolto incorrettamente!";
	$lang['errormessage8'] = "Quest'utente non riceverà e-mail!";
	$lang['errormessage9'] = "E' avvenuto un errore nel tentativo di spedire la tua e-mail!";
	$lang['security_code'] = "codice di sicurezza (captcha)";
	$lang['captcha_what_is_that'] = "Cos'è questo?";
	$lang['captcha_wikipedia'] = "http://it.wikipedia.org/wiki/CAPTCHA";
	$lang['captcha_tooltip'] = "Un nuovo post nel guestbook entry una eMail richiede di risolvere il captcha per impedire post automatici da parte di programmi. Per favore digita tutte le lettere MAIUSCOLE. Se il codice è illeggibile, lascia il campo vuoto e clicca su ''Invia''. In questo modo verrà generato un nuovo captcha. I dati negli altri campi verranno mantenuti. Se non viene generato un nuovo codice, per favore eseguire un clic con il tasto destro del mouse e ''ricaricare'' oppure premere [CTRL]+[R].";
	$lang['back_to_mainpage'] = "Torna alla pagina principale";
	$lang['back'] = "Indietro";
	$lang['entry_success_mod'] = "Il tuo post è stato salvato con successo.<br>Sarà validato dall'admin e poi pubblicato.";
	$lang['entry_success'] = "Il tuo post è stato salvato con successo. Puoi vederlo subito.";
	$lang['forwarding'] = "Sarai redirettato automaticamente entro 5 secondi. Se così non fosse, clicca su ''Torna alla pagina principale''.";
	$lang['bbcodes'] = "BBCodes:";
	$lang['bbcode_help_bold'] = "grassetto";
	$lang['bbcode_help_italic'] = "corsivo";
	$lang['bbcode_help_url'] = "ancora";
	$lang['bbcode_textsize'] = "grandezza del testo";
	$lang['bbcode_extrasmall'] = "piccolissimo";
	$lang['bbcode_small'] = "piccolo";
	$lang['bbcode_default'] = "normale";
	$lang['bbcode_big'] = "grande";
	$lang['bbcode_extrabig'] = "grandissimo";
	$lang['bbcode_textcolor'] = "colore del testo";
	$lang['bbcode_help_size'] = "grandezza del testo";
	$lang['smileys'] = "smileys:";
	$lang['sendmail_admin_title'] = "Nuovo post da '{NAME}'";
	$lang['sendmail_user_title'] = "Il tuo post presso {DOMAIN}";

	// ITALIAN strings of email.php
	$lang['email_name'] = "Il tuo nome:";
	$lang['email_email'] = "La tua eMail:";
	$lang['email_message'] = "Il tuo messaggio:";
	$lang['email_sent_to'] = "Questa eMail verrà spedita a:";
	$lang['email_send'] = "Invia";
	$lang['email_caption'] = "eMail da '{NAME}' sul guestbook di {DOMAIN}";
	$lang['email_sender'] = "Mittente:";
	$lang['email_receiver'] = "Destinatario:";
	$lang['email_from'] = "da:";
	$lang['email_sendcopytome'] = "Voglio ricevere una copia di questa eMail.";
	$lang['email_success'] = "La tua email è stata spedita con successo all'utente.";
	$lang['email_fail'] = "Your eMail couldn't be sent. Maybe there is a problem with the mail server.";
?>
